@@ -1780,12 +1780,6 @@ mod tests {
         assert_eq!(&a / &b, [-1., -0.5, 0.75][..].into());
     }
 
-    #[test]
-    fn test_exp() {
-        let a: ArrayExt<f32> = [0.5, 1.0, 1.5, 2.0][..].into();
-        a.exp();
-    }
-
     #[test]
     fn test_pow() {
         let a: Array = [1, 2, 3][..].into();
